@@ -26,4 +26,4 @@ class FlagSetter:
                 self.set_flag_data(flag)
 
     def set_flag_data(self, variant, experiment=None):
-        variant.set_for_evaluation(self.parser, experiment, self.impression_invoker)
+        variant.set_for_evaluation(self.parser, self.impression_invoker, experiment)
